##  Discovery Capabilities
Okta integration offers the following capabilities:
Available Capabilities | Description | Okta Resource
---|---|---
SaaS Discovery (Standard) | SaaS discovery automatically identifies your organization's SaaS applications. | Discovered apps


You get the following information about the discovered SaaS:
Field | Description
---|---
Status | States whether an application in Okta is set to active or inactive.
Sign-on Mode | Indicates the authentication protocol used by users to sign in.
Creation Timestamp | Indicates when the application was created in Okta.
Last Modified | Indicates the last time the application's information was updated in the Okta system. This attribute provides information about the timeliness of the application's configuration data.
Last seen at | Last time the discovered SaaS was seen in the source system
Item status in source |  Status of the discovered SaaS in the source system. It can be the following:
  * Active: The application has been seen in Okta in the last week.
  * Inactive: The application has not been seen in the last week.
  * Deleted: The application is no longer detected in the source system as it no longer exists in the SSO




